pub type MessageDigest = Digest;Aliased Type
pub struct MessageDigest {
pub hash: String,
pub size_bytes: i64,
}Fields
hash: StringThe hash, represented as a lowercase hexadecimal string, padded with leading zeroes up to the hash function length.
size_bytes: i64The size of the blob, in bytes.